@@ -8,10 +8,10 @@
 
 #include <KCalCore/Todo>
 
-#include <AkonadiCore/Akonadi/AttributeFactory>
-#include <AkonadiCore/Akonadi/CollectionFetchScope>
-#include <AkonadiCore/Akonadi/ItemFetchScope>
-#include <AkonadiCore/Akonadi/Monitor>
+#include <Akonadi/AttributeFactory>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/Monitor>
 
 #include "akonadi/akonadiapplicationselectedattribute.h"
 #include "akonadi/akonaditimestampattribute.h"
@@ -23,11 +23,7 @@ namespace
     template<typename T>
     QSet<T> listToSet(const QList<T> &list)
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        return list.toSet();
-#else
         return {list.cbegin(), list.cend()};
-#endif
     }
 }
 
