@@ -1,25 +1,7 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "akonadiprojectqueries.h"
@@ -38,7 +20,7 @@ ProjectQueries::ProjectQueries(const StorageInterface::Ptr &storage, const Seria
 
 ProjectQueries::ProjectResult::Ptr ProjectQueries::findAll() const
 {
-    auto fetch = m_helpers->fetchItems();
+    auto fetch = m_helpers->fetchItems(const_cast<ProjectQueries*>(this));
     auto predicate = [this] (const Akonadi::Item &item) {
         return m_serializer->isProjectItem(item);
     };
@@ -50,7 +32,7 @@ ProjectQueries::TaskResult::Ptr ProjectQueries::findTopLevel(Domain::Project::Pt
 {
     Akonadi::Item item = m_serializer->createItemFromProject(project);
     auto &query = m_findTopLevel[item.id()];
-    auto fetch = m_helpers->fetchSiblings(item);
+    auto fetch = m_helpers->fetchSiblings(item, const_cast<ProjectQueries*>(this));
     auto predicate = [this, project] (const Akonadi::Item &item) {
         return m_serializer->isProjectChild(project, item);
     };
