@@ -7,9 +7,9 @@
 
 #include "akonadiserializer.h"
 
-#include <AkonadiCore/Akonadi/Collection>
-#include <AkonadiCore/Akonadi/EntityDisplayAttribute>
-#include <AkonadiCore/Akonadi/Item>
+#include <Akonadi/Collection>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/Item>
 #include <KCalCore/Todo>
 #if __has_include(<kcalcore_version.h>)
 #include <kcalcore_version.h>
@@ -169,7 +169,7 @@ void Serializer::updateTaskFromItem(Domain::Task::Ptr task, Item item)
     task->setProperty("relatedUid", todo->relatedTo());
     task->setRunning(todo->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsRunning()) == QLatin1String("1"));
     const auto contextUids = todo->customProperty(Serializer::customPropertyAppName(),
-                                                  Serializer::customPropertyContextList()).split(',', QString::SkipEmptyParts);
+                                                  Serializer::customPropertyContextList()).split(',', Qt::SkipEmptyParts);
     task->setProperty("contextUids", contextUids);
 
     switch (todo->recurrence()->recurrenceType()) {
@@ -196,7 +196,6 @@ void Serializer::updateTaskFromItem(Domain::Task::Ptr task, Item item)
     attachments.reserve(attachmentsInput.size());
     std::transform(attachmentsInput.cbegin(), attachmentsInput.cend(),
                    std::back_inserter(attachments),
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 11, 80)
                    [&mimeDb] (const KCalCore::Attachment &attach) {
                        Domain::Task::Attachment attachment;
                        if (attach.isUri())
@@ -208,19 +207,6 @@ void Serializer::updateTaskFromItem(Domain::Task::Ptr task, Item item)
                        attachment.setIconName(mimeDb.mimeTypeForName(attach.mimeType()).iconName());
                        return attachment;
                    });
-#else
-                   [&mimeDb] (const KCalCore::Attachment::Ptr &attach) {
-                       Domain::Task::Attachment attachment;
-                       if (attach->isUri())
-                           attachment.setUri(QUrl(attach->uri()));
-                       else
-                           attachment.setData(attach->decodedData());
-                       attachment.setLabel(attach->label());
-                       attachment.setMimeType(attach->mimeType());
-                       attachment.setIconName(mimeDb.mimeTypeForName(attach->mimeType()).iconName());
-                       return attachment;
-                   });
-#endif
     task->setAttachments(attachments);
 }
 
@@ -283,7 +269,6 @@ Akonadi::Item Serializer::createItemFromTask(Domain::Task::Ptr task)
     }
 
     for (const auto &attachment : task->attachments()) {
-#if KCALCORE_VERSION >= QT_VERSION_CHECK(5, 11, 80)
         KCalCore::Attachment attach(QByteArray{});
         if (attachment.isUri())
             attach.setUri(attachment.uri().toString());
@@ -291,15 +276,6 @@ Akonadi::Item Serializer::createItemFromTask(Domain::Task::Ptr task)
             attach.setDecodedData(attachment.data());
         attach.setMimeType(attachment.mimeType());
         attach.setLabel(attachment.label());
-#else
-        KCalCore::Attachment::Ptr attach(new KCalCore::Attachment(QByteArray()));
-        if (attachment.isUri())
-            attach->setUri(attachment.uri().toString());
-        else
-            attach->setDecodedData(attachment.data());
-        attach->setMimeType(attachment.mimeType());
-        attach->setLabel(attachment.label());
-#endif
         todo->addAttachment(attach);
     }
 
@@ -484,7 +460,7 @@ bool Serializer::isProjectChild(Domain::Project::Ptr project, Item item)
 static QStringList extractContexts(KCalCore::Todo::Ptr todo)
 {
     const QString contexts = todo->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyContextList());
-    return contexts.split(',', QString::SkipEmptyParts);
+    return contexts.split(',', Qt::SkipEmptyParts);
 }
 
 bool Serializer::isContextChild(Domain::Context::Ptr context, Item item) const
