@@ -1,25 +1,7 @@
-/* This file is part of Zanshin
-
-   Copyright 2016 David Faure <faure@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2016 David Faure <faure@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "runningtaskwidget.h"
 #include "runningtaskmodelinterface.h"
@@ -56,7 +38,7 @@ RunningTaskWidget::RunningTaskWidget(QWidget *parent)
     // Current idea for a good background color:
     // the selection color, i.e. usually blue. Arguable ;)
     QPalette pal;
-    pal.setBrush(QPalette::Background, pal.brush(QPalette::Highlight));
+    pal.setBrush(QPalette::Window, pal.brush(QPalette::Highlight));
     setPalette(pal);
     setAutoFillBackground(true);
 
