@@ -1,26 +1,9 @@
-/* This file is part of Zanshin
-
-   Copyright 2015 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+/*
+ * SPDX-FileCopyrightText: 2015 Kevin Ottens <ervin@kde.org>
+ SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+
 #include <testlib/qtest_zanshin.h>
 
 #include <KCalCore/Todo>
@@ -75,9 +58,9 @@ private:
         return Akonadi::SerializerInterface::Ptr(new Akonadi::Serializer);
     }
 
-    auto fetchCollectionsFunction(Akonadi::StorageInterface::Ptr storage) {
-        return [storage] (const Domain::LiveQueryInput<Akonadi::Collection>::AddFunction &add) {
-            auto job = storage->fetchCollections(Akonadi::Collection::root(), Akonadi::Storage::Recursive);
+    auto fetchCollectionsFunction(Akonadi::StorageInterface::Ptr storage, QObject *parent) {
+        return [storage, parent] (const Domain::LiveQueryInput<Akonadi::Collection>::AddFunction &add) {
+            auto job = storage->fetchCollections(Akonadi::Collection::root(), Akonadi::Storage::Recursive, parent);
             Utils::JobHandler::install(job->kjob(), [add, job] {
                 foreach (const auto &col, job->collections()) {
                     add(col);
@@ -86,12 +69,12 @@ private:
         };
     }
 
-    auto fetchItemsInAllCollectionsFunction(Akonadi::StorageInterface::Ptr storage) {
-        return [storage] (const Domain::LiveQueryInput<Akonadi::Item>::AddFunction &add) {
-            auto job = storage->fetchCollections(Akonadi::Collection::root(), Akonadi::Storage::Recursive);
+    auto fetchItemsInAllCollectionsFunction(Akonadi::StorageInterface::Ptr storage, QObject *parent) {
+        return [storage, parent] (const Domain::LiveQueryInput<Akonadi::Item>::AddFunction &add) {
+            auto job = storage->fetchCollections(Akonadi::Collection::root(), Akonadi::Storage::Recursive, parent);
             Utils::JobHandler::install(job->kjob(), [add, job, storage] {
                 foreach (const auto &col, job->collections()) {
-                    auto itemJob = storage->fetchItems(col);
+                    auto itemJob = storage->fetchItems(col, nullptr);
                     Utils::JobHandler::install(itemJob->kjob(), [add, itemJob] {
                         foreach (const auto &item, itemJob->items())
                             add(item);
@@ -101,16 +84,16 @@ private:
         };
     }
 
-    auto fetchItemsInSelectedCollectionsFunction(Akonadi::StorageInterface::Ptr storage, Akonadi::SerializerInterface::Ptr serializer)
+    auto fetchItemsInSelectedCollectionsFunction(Akonadi::StorageInterface::Ptr storage, Akonadi::SerializerInterface::Ptr serializer, QObject *parent)
     {
-        return [storage, serializer] (const Domain::LiveQueryInput<Akonadi::Item>::AddFunction &add) {
-            auto job = storage->fetchCollections(Akonadi::Collection::root(), Akonadi::Storage::Recursive);
+        return [storage, serializer, parent] (const Domain::LiveQueryInput<Akonadi::Item>::AddFunction &add) {
+            auto job = storage->fetchCollections(Akonadi::Collection::root(), Akonadi::Storage::Recursive, parent);
             Utils::JobHandler::install(job->kjob(), [add, job, storage, serializer] {
                 foreach (const auto &col, job->collections()) {
                     if (!serializer->isSelectedCollection(col))
                         continue;
 
-                    auto itemJob = storage->fetchItems(col);
+                    auto itemJob = storage->fetchItems(col, nullptr);
                     Utils::JobHandler::install(itemJob->kjob(), [add, itemJob] {
                         foreach (const auto &item, itemJob->items())
                             add(item);
@@ -140,7 +123,7 @@ private slots:
 
         auto query = Domain::LiveQueryOutput<Domain::Context::Ptr>::Ptr();
         auto fetch = [storage, collection] (const Domain::LiveQueryInput<Akonadi::Item>::AddFunction &add) {
-            auto job = storage->fetchItems(collection);
+            auto job = storage->fetchItems(collection, nullptr);
             Utils::JobHandler::install(job->kjob(), [add, job] {
                 foreach (const auto &item, job->items()) {
                     add(item);
@@ -255,7 +238,7 @@ private slots:
         auto inQuery = Domain::LiveQueryOutput<Domain::Context::Ptr>::Ptr();
         auto exQuery = Domain::LiveQueryOutput<Domain::Context::Ptr>::Ptr();
         auto fetch = [storage, collection] (const Domain::LiveQueryInput<Akonadi::Item>::AddFunction &add) {
-            auto job = storage->fetchItems(collection);
+            auto job = storage->fetchItems(collection, nullptr);
             Utils::JobHandler::install(job->kjob(), [add, job] {
                 foreach (const auto &item, job->items()) {
                     add(item);
@@ -307,7 +290,7 @@ private slots:
         auto storage = createStorage(data);
 
         auto query = Domain::LiveQueryOutput<Domain::DataSource::Ptr>::Ptr();
-        auto fetch = fetchCollectionsFunction(storage);
+        auto fetch = fetchCollectionsFunction(storage, nullptr);
         auto predicate = [] (const Akonadi::Collection &collection) {
             return collection.name().endsWith(QLatin1String("-in"));
         };
@@ -410,7 +393,7 @@ private slots:
 
         auto inQuery = Domain::LiveQueryOutput<Domain::DataSource::Ptr>::Ptr();
         auto exQuery = Domain::LiveQueryOutput<Domain::DataSource::Ptr>::Ptr();
-        auto fetch = fetchCollectionsFunction(storage);
+        auto fetch = fetchCollectionsFunction(storage, nullptr);
         auto inPredicate = [] (const Akonadi::Collection &collection) {
             return collection.name().endsWith(QLatin1String("-in"));
         };
@@ -461,7 +444,7 @@ private slots:
         auto storage = createStorage(data);
 
         auto query = Domain::LiveQueryOutput<Domain::Project::Ptr>::Ptr();
-        auto fetch = fetchItemsInAllCollectionsFunction(storage);
+        auto fetch = fetchItemsInAllCollectionsFunction(storage, nullptr);
         auto predicate = [] (const Akonadi::Item &item) {
             return titleFromItem(item).endsWith(QLatin1String("-in"));
         };
@@ -572,7 +555,7 @@ private slots:
 
         auto inQuery = Domain::LiveQueryOutput<Domain::Project::Ptr>::Ptr();
         auto exQuery = Domain::LiveQueryOutput<Domain::Project::Ptr>::Ptr();
-        auto fetch = fetchItemsInAllCollectionsFunction(storage);
+        auto fetch = fetchItemsInAllCollectionsFunction(storage, nullptr);
         auto inPredicate = [] (const Akonadi::Item &item) {
             return titleFromItem(item).endsWith(QLatin1String("-in"));
         };
@@ -621,7 +604,7 @@ private slots:
         auto serializer = createSerializer();
 
         auto query = Domain::LiveQueryOutput<Domain::Project::Ptr>::Ptr();
-        auto fetch = fetchItemsInSelectedCollectionsFunction(storage, serializer);
+        auto fetch = fetchItemsInSelectedCollectionsFunction(storage, serializer, nullptr);
         auto predicate = [] (const Akonadi::Item &) {
             return true;
         };
@@ -665,7 +648,7 @@ private slots:
         auto storage = createStorage(data);
 
         auto query = Domain::LiveQueryOutput<Domain::Task::Ptr>::Ptr();
-        auto fetch = fetchItemsInAllCollectionsFunction(storage);
+        auto fetch = fetchItemsInAllCollectionsFunction(storage, nullptr);
         auto predicate = [] (const Akonadi::Item &item) {
             return titleFromItem(item).endsWith(QLatin1String("-in"));
         };
@@ -771,7 +754,7 @@ private slots:
 
         auto inQuery = Domain::LiveQueryOutput<Domain::Task::Ptr>::Ptr();
         auto exQuery = Domain::LiveQueryOutput<Domain::Task::Ptr>::Ptr();
-        auto fetch = fetchItemsInAllCollectionsFunction(storage);
+        auto fetch = fetchItemsInAllCollectionsFunction(storage, nullptr);
         auto inPredicate = [] (const Akonadi::Item &item) {
             return titleFromItem(item).endsWith(QLatin1String("-in"));
         };
@@ -820,7 +803,7 @@ private slots:
         auto serializer = createSerializer();
 
         auto query = Domain::LiveQueryOutput<Domain::Task::Ptr>::Ptr();
-        auto fetch = fetchItemsInSelectedCollectionsFunction(storage, serializer);
+        auto fetch = fetchItemsInSelectedCollectionsFunction(storage, serializer, nullptr);
         auto predicate = [] (const Akonadi::Item &) {
             return true;
         };
